import { isPunctualOrRecurrent } from '../../../core/dtos/validators/is-punctual-or-recurrent';
import { Frequency } from '../../../interface/commands/frequency.enum';

describe('punctual or recurrent validators', () => {
  describe('punctual case ', () => {
    describe('valid cases', () => {
      it('should validate with valid departure', () => {
        expect(
          isPunctualOrRecurrent({
            value: undefined,
            constraints: [],
            targetName: '',
            object: {
              frequency: Frequency.PUNCTUAL,
              departure: new Date('2023-02-01T18:00:00+02:00'),
            },
            property: '',
          }),
        ).toBeTruthy();
      });
    });
    describe('invalid cases ', () => {
      it('should not validate without departure', () => {
        expect(
          isPunctualOrRecurrent({
            value: undefined,
            constraints: [],
            targetName: '',
            object: {
              frequency: Frequency.PUNCTUAL,
            },
            property: '',
          }),
        ).toBeFalsy();
      });
    });
  });
  describe('recurrent case ', () => {
    describe('valid cases', () => {
      it('should validate with valid from date, to date and non empty schedule', () => {
        expect(
          isPunctualOrRecurrent({
            value: undefined,
            constraints: [],
            targetName: '',
            object: {
              frequency: Frequency.RECURRENT,
              fromDate: new Date('2023-01-15'),
              toDate: new Date('2023-06-30'),
              schedule: {
                mon: '08:30',
              },
            },
            property: '',
          }),
        ).toBeTruthy();
      });
    });
    describe('invalid cases ', () => {
      it('should not validate with empty schedule', () => {
        expect(
          isPunctualOrRecurrent({
            value: undefined,
            constraints: [],
            targetName: '',
            object: {
              frequency: Frequency.RECURRENT,
              fromDate: new Date('2023-01-15'),
              toDate: new Date('2023-06-30'),
              schedule: {},
            },
            property: '',
          }),
        ).toBeFalsy();
      });
      it('should not validate with invalid from date to date and empty schedule and margin', () => {
        expect(
          isPunctualOrRecurrent({
            value: undefined,
            constraints: [],
            targetName: '',
            object: {
              frequency: Frequency.RECURRENT,
              departure: new Date('2023-10-20'),
              toDate: new Date('2023-10-30'),
            },
            property: '',
          }),
        ).toBeFalsy();
      });
    });
  });
});
