import { Waypoint } from '../../../interface/commands/waypoint';
import { hasValidPositionIndexes } from '../../../core/dtos/validators/waypoint-position';
describe('addresses position validators', () => {
  const mockAddress1: Waypoint = {
    lon: 48.68944505415954,
    lat: 6.176510296462267,
    houseNumber: '5',
    street: 'Avenue Foch',
    locality: 'Nancy',
    postalCode: '54000',
    country: 'France',
  };
  const mockAddress2: Waypoint = {
    lon: 48.8566,
    lat: 2.3522,
    locality: 'Paris',
    postalCode: '75000',
    country: 'France',
  };

  const mockAddress3: Waypoint = {
    lon: 49.2628,
    lat: 4.0347,
    locality: 'Reims',
    postalCode: '51454',
    country: 'France',
  };
  it('should validate if none of position is definded ', () => {
    expect(
      hasValidPositionIndexes([mockAddress1, mockAddress2, mockAddress3]),
    ).toBeTruthy();
  });
  it('should throw an error if position are partialy defined ', () => {
    mockAddress1.position = 0;
    expect(
      hasValidPositionIndexes([mockAddress1, mockAddress2, mockAddress3]),
    ).toBeFalsy();
  });
  it('should throw an error if position are partialy defined ', () => {
    mockAddress1.position = 0;
    mockAddress2.position = null;
    mockAddress3.position = undefined;
    expect(
      hasValidPositionIndexes([mockAddress1, mockAddress2, mockAddress3]),
    ).toBeFalsy();
  });

  it('should throw an error if positions are not incremented  ', () => {
    mockAddress1.position = 0;
    mockAddress2.position = 1;
    mockAddress3.position = 1;
    expect(
      hasValidPositionIndexes([mockAddress1, mockAddress2, mockAddress3]),
    ).toBeFalsy();
  });
  it('should validate if all positions are defined and incremented', () => {
    mockAddress1.position = 0;
    mockAddress2.position = 1;
    mockAddress3.position = 2;
    expect(
      hasValidPositionIndexes([mockAddress1, mockAddress2, mockAddress3]),
    ).toBeTruthy();
    mockAddress1.position = 10;
    mockAddress2.position = 0;
    mockAddress3.position = 3;
    expect(
      hasValidPositionIndexes([mockAddress1, mockAddress2, mockAddress3]),
    ).toBeTruthy();
  });
});
